@@ -126,10 +126,31 @@ class Tier(object):
 
         if self.is_autoscalable:
             # autoscaling group (asg) create-or-update and setup scale-up policy
-            pol = self.tier_parser.add_parser("as-configure", help="Create/Update autoscaling group and associate policy")
-            pol.add_argument("-r", "--region", help="Region where the tier will be located",
+            create_update = self.tier_parser.add_parser("create-update", help="Create/update autoscale Tier. "
+                                                                "Command will return after instance is in running state")
+            create_update.add_argument("-a", "--ami-id", help="AMI ID to use for the CRON tier",
+                                default=self.ami, dest="ami")
+            create_update.add_argument("-z", "--zone", help="AWS Availibility Zone",
+                                default=self.az, dest="zone")
+            create_update.add_argument("-c", "--cooldown", help="Default cooldown",
+                                default='600', dest="cooldown")
+            create_update.add_argument("-g", "--health_check_grace", help="Health check grace",
+                                default='600', dest="health_check_grace")
+            create_update.add_argument("-r", "--region", help="Region where the tier will be located",
                                 default=self.region, dest="region")
-            pol.set_defaults(func=self.asg)
+            create_update.add_argument("-i", "--instance-type", help="Instance Type of the machine",
+                                choices=["m3.large", "m3.xlarge", "r3.large", "r3.xlarge", "r3.2xlarge", "m1.large", "m1.xlarge"], dest="instance_type",
+                                default=self.instance_type)
+            create_update.add_argument("-t", "--tunnel", dest="tunnel",
+                                action="store_true", help="Use a tunnel through a web node")
+            
+            create_update.add_argument("-d", "--alarm-threshold", help="As policy alarm threshold",
+                                default='100', dest="threshold")
+            create_update.add_argument("-l", "--alarm-period", help="As policy alarm period",
+                                default='300', dest="period")
+            create_update.add_argument("-p", "--policy_adjustment", help="As policy adjustment",
+                                default='1', dest="adjustment")
+            create_update.set_defaults(func=self.asg)
 
     def deploy(self, args):
         knife = Knife()
@@ -225,17 +246,17 @@ class Tier(object):
         user_data = src.safe_substitute(d)
 
         autoscale_conn = boto.ec2.autoscale.connect_to_region(
-            self.region,
+            args.region,
             aws_access_key_id=creds["access"],
             aws_secret_access_key=creds["secret"])
 
         new_launch_config = LaunchConfiguration(
                 name=as_lc_name,
-                image_id=self.ami,
+                image_id=args.ami,
                 key_name=key_name,
                 security_groups=self.security_groups,
                 user_data=user_data,
-                instance_type=self.instance_type)
+                instance_type=args.instance_type)
 
         for lc in autoscale_conn.get_all_launch_configurations():
             if re.match(str(as_lc_name), lc.name):
@@ -247,14 +268,14 @@ class Tier(object):
 
         as_group = AutoScalingGroup(
                 name=as_group_name,
-                availability_zones=[self.az],
+                availability_zones=[args.zone],
                 launch_config=new_launch_config,
                 min_size=1,
                 max_size=4,
                 desired_capacity=1,
                 connection=autoscale_conn,
-                default_cooldown=1200,
-                health_check_period='600')
+                default_cooldown=args.cooldown,
+                health_check_period=args.health_check_grace)
         for group in autoscale_conn.get_all_groups():
             if re.match(as_group_name, group.name):
                 logging.warn("%s autoscale group '%s' already exists!" % (self.tier, group.name))
@@ -295,8 +316,8 @@ class Tier(object):
             name=policy_name,
             adjustment_type="ChangeInCapacity",
             as_name=as_group_name,
-            scaling_adjustment=1,
-            cooldown=1200)
+            scaling_adjustment=args.adjustment,
+            cooldown=args.cooldown)
         autoscale_conn.create_scaling_policy(policy)
         policies = autoscale_conn.get_all_policies(as_group=as_group_name)
         assert len(policies) == 1, "Found multiple (%s) autoscaling policies!" % as_group_name
@@ -316,8 +337,8 @@ class Tier(object):
                 metric='DJWaitTime',
                 statistic='Average',
                 comparison='>',
-                threshold=150,
-                period=300,
+                threshold=args.threshold,
+                period=args.period,
                 evaluation_periods=1,
                 alarm_actions=[policy.policy_arn],
                 dimensions={})
