@@ -18,9 +18,10 @@ class Web(Tier):
         modules = ["hive_scripts", "hadoop", "hadoop2", "hustler", "hive", "hive13", "hive2", "sqoop", "pig", "tapp2", "cloudman", "cluster_proxy"]
         run_list = '{"run_list":["recipe[webslave]"], "qubole_tier":"%s", "worker_name": "%s"}'
         worker = "qpal_worker"
-        ami = "ami-1327167a"
+        ami = "ami-0edbb766"
         region = "us-east-1"
-        super(Web, self).__init__(tier=tier, run_list=run_list, ami=ami, modules=modules, worker=worker, region=region)
+        az = "us-east-1d"
+        super(Web, self).__init__(tier=tier, run_list=run_list, ami=ami, modules=modules, worker=worker, region=region, az=az)
         self.is_autoscalable = True
 
     def configure_parsers(self):
